Learn R Programming

gamlss.dist (version 6.1-11)

SEP1: The Skew exponential power type 1-4 distribution for fitting a GAMLSS

Description

These functions define the Skew Power exponential type 1 to 4 distributions. All of them are four parameter distributions and can be used to fit a GAMLSS model. The functions dSEP1, dSEP2, dSEP3 and dSEP4 define the probability distribution functions, the functions pSEP1, pSEP2, pSEP3 and pSEP4 define the cumulative distribution functions the functions qSEP1, qSEP2, qSEP3 and qSEP4 define the inverse cumulative distribution functions and the functions rSEP1, rSEP2, rSEP3 and rSEP4 define the random generation for the Skew exponential power distributions.

Usage

SEP1(mu.link = "identity", sigma.link = "log", nu.link = "identity", 
     tau.link = "log")
dSEP1(x, mu = 0, sigma = 1, nu = 0, tau = 2, log = FALSE)
pSEP1(q, mu = 0, sigma = 1, nu = 0, tau = 2, lower.tail = TRUE, 
     log.p = FALSE)
qSEP1(p, mu = 0, sigma = 1, nu = 0, tau = 2, lower.tail = TRUE, 
     log.p = FALSE)
rSEP1(n, mu = 0, sigma = 1, nu = 0, tau = 2)

SEP2(mu.link = "identity", sigma.link = "log", nu.link = "identity", tau.link = "log") dSEP2(x, mu = 0, sigma = 1, nu = 0, tau = 2, log = FALSE) pSEP2(q, mu = 0, sigma = 1, nu = 0, tau = 2, lower.tail = TRUE, log.p = FALSE) qSEP2(p, mu = 0, sigma = 1, nu = 0, tau = 2, lower.tail = TRUE, log.p = FALSE) rSEP2(n, mu = 0, sigma = 1, nu = 0, tau = 2)

SEP3(mu.link = "identity", sigma.link = "log", nu.link = "log", tau.link = "log") dSEP3(x, mu = 0, sigma = 1, nu = 2, tau = 2, log = FALSE) pSEP3(q, mu = 0, sigma = 1, nu = 2, tau = 2, lower.tail = TRUE, log.p = FALSE) qSEP3(p, mu = 0, sigma = 1, nu = 2, tau = 2, lower.tail = TRUE, log.p = FALSE)

SEP4(mu.link = "identity", sigma.link = "log", nu.link = "log", tau.link = "log") dSEP4(x, mu = 0, sigma = 1, nu = 2, tau = 2, log = FALSE) pSEP4(q, mu = 0, sigma = 1, nu = 2, tau = 2, lower.tail = TRUE, log.p = FALSE) qSEP4(p, mu = 0, sigma = 1, nu = 2, tau = 2, lower.tail = TRUE, log.p = FALSE) rSEP4(n, mu = 0, sigma = 1, nu = 2, tau = 2)

Arguments

Value

SEP2() returns a gamlss.family object which can be used to fit the SEP2 distribution in the gamlss() function. dSEP2() gives the density, pSEP2() gives the distribution function, qSEP2() gives the quantile function, and rSEP2()

generates random deviates.

Details

The probability density function of the Skew Power exponential distribution type 1, (SEP1), is defined as

$$f_Y(y|\mu,\sigma\,\nu,\tau)=\frac{2}{\sigma} f_{Z_1}(z) F_{Z_1}(\nu z)$$

for \( -\infty < y < \infty \), \(-\infty<\mu <\infty\), \(\sigma>0\), \(-\infty<\nu <\infty\), and \(\tau>0\) where \(z=(y-\mu)/\sigma\), and \(Z_1 \sim \texttt{PE2}(0, \tau^{1/\tau }, \tau) \), see pp 401-402 of Rigby et al. (2019).

The probability density function of the Skew Power exponential distribution type 2, (SEP2), is defined as

$$f_Y(y|\mu,\sigma\,\nu,\tau)=\frac{2}{\sigma} f_{Z_1}(z) \Phi_{Z_1}(\omega)$$

for \( -\infty < y < \infty \), \(-\infty<\mu <\infty\), \(\sigma>0\), \(-\infty<\nu <\infty\), and \(\tau>0\) where \(z=(y-\mu)/\sigma\), and \(\omega= \texttt{sign}(z) |z|^{\tau/2} \nu \sqrt{2/\tau}\), and \(Z_1 \sim \texttt{PE2}(0, \tau^{1/\tau }, \tau) \), see pp 402-404 of Rigby et al. (2019).

For SEP3 and SEP3 see pp 404-406 and pp 407-408 of Rigby et al. (2019), respectively.

References

Fernadez C., Osiewalski J. and Steel M.F.J.(1995) Modelling and inference with v-spherical distributions. JASA, 90, pp 1331-1340.

Rigby, R. A. and Stasinopoulos D. M. (2005). Generalized additive models for location, scale and shape,(with discussion), Appl. Statist., 54, part 3, pp 507-554.

Rigby, R. A., Stasinopoulos, D. M., Heller, G. Z., and De Bastiani, F. (2019) Distributions for modeling location, scale, and shape: Using GAMLSS in R, Chapman and Hall/CRC, tools:::Rd_expr_doi("10.1201/9780429298547"). An older version can be found in https://www.gamlss.com/.

Stasinopoulos D. M. Rigby R.A. (2007) Generalized additive models for location scale and shape (GAMLSS) in R. Journal of Statistical Software, Vol. 23, Issue 7, Dec 2007, tools:::Rd_expr_doi("10.18637/jss.v023.i07").

Stasinopoulos D. M., Rigby R.A., Heller G., Voudouris V., and De Bastiani F., (2017) Flexible Regression and Smoothing: Using GAMLSS in R, Chapman and Hall/CRC. tools:::Rd_expr_doi("10.1201/b21973")

(see also https://www.gamlss.com/).

See Also

gamlss.family, SEP

Examples

Run this code
SEP1() 
curve(dSEP4(x, mu=5 ,sigma=1, nu=2, tau=1.5), -2, 10, 
          main = "The SEP4  density mu=5 ,sigma=1, nu=1, tau=1.5")
# library(gamlss)
#y<- rSEP4(100, mu=5, sigma=1, nu=2, tau=1.5);hist(y)
#m1<-gamlss(y~1, family=SEP1, n.cyc=50)
#m2<-gamlss(y~1, family=SEP2, n.cyc=50)
#m3<-gamlss(y~1, family=SEP3, n.cyc=50)
#m4<-gamlss(y~1, family=SEP4, n.cyc=50) 
#GAIC(m1,m2,m3,m4)

Run the code above in your browser using DataLab