gamlss.family object to be used for a
GAMLSS fitting using the function gamlss(). The functions dBCPE,
pBCPE, qBCPE and rBCPE define the density, distribution function, quantile function and random
generation for the Box-Cox Power Exponential distribution.
The function checkBCPE can be used, typically when a BCPE model is fitted, to check whether there exit a turning point
of the distribution close to zero. It give the number of values of the response below their minimum turning point and also
the maximum probability of the lower tail below minimum turning point.
[The function Biventer() is the original version of the function suitable only
for the untruncated BCPE distribution.] See Rigby and Stasinopoulos (2003) for details.
The function BCPEo is identical to BCPE but with log link for mu.BCPE(mu.link = "identity", sigma.link = "log", nu.link = "identity",
tau.link = "log")
BCPEo(mu.link = "log", sigma.link = "log", nu.link = "identity",
tau.link = "log")
BCPEuntr(mu.link = "identity", sigma.link = "log", nu.link = "identity",
tau.link = "log")
dBCPE(x, mu = 5, sigma = 0.1, nu = 1, tau = 2, log = FALSE)
pBCPE(q, mu = 5, sigma = 0.1, nu = 1, tau = 2, lower.tail = TRUE, log.p = FALSE)
qBCPE(p, mu = 5, sigma = 0.1, nu = 1, tau = 2, lower.tail = TRUE, log.p = FALSE)
rBCPE(n, mu = 5, sigma = 0.1, nu = 1, tau = 2)
checkBCPE(obj = NULL, mu = 10, sigma = 0.1, nu = 0.5, tau = 2,...)mu.link, with "identity" link as the default for the mu parameter. Other links are "inverse", "log" and "own"sigma.link, with "log" link as the default for the sigma parameter. Other links are "inverse", "identity" and "own"nu.link, with "identity" link as the default for the nu parameter. Other links are "inverse", "log" and "own"tau.link, with "log" link as the default for the tau parameter. Other links are "logshifted", "identity" and "own"nu parameter valuestau parameter valueslength(n) > 1, the length is
taken to be the number requiredBCPE() returns a gamlss.family object which can be used to fit a Box Cox Power Exponential distribution in the gamlss() function.
dBCPE() gives the density, pBCPE() gives the distribution
function, qBCPE() gives the quantile function, and rBCPE()
generates random deviates.BCPE.untr distribution may be unsuitable for some combinations of the parameters (mainly for large $\sigma$)
where the integrating constant is less than 0.99. A warning will be given if this is the case.
The BCPE distribution is suitable for all combinations of the parameters within their ranges [i.e. $\mu>0,\sigma>0, \nu=(-\infty,\infty) {\rm and} \tau>0$ ]BCPE.untr), is defined as
$$f(y|\mu,\sigma,\nu,\tau)=\frac{y^{\nu-1} \tau \exp[-\frac{1}{2}|\frac{z}{c}|^\tau]}{\mu^{\nu} \sigma c 2^{(1+1/\tau)} \Gamma(\frac{1}{\tau})}$$
where $c = [ 2^{(-2/\tau)}\Gamma(1/\tau)/\Gamma(3/\tau)]^{0.5}$,
where if $\nu \neq 0$ then $z=[(y/\mu)^{\nu}-1]/(\nu \sigma)$
else $z=\log(y/\mu)/\sigma$,
for $y>0$, $\mu>0$, $\sigma>0$, $\nu=(-\infty,+\infty)$ and $\tau>0$.
The Box-Cox Power Exponential, BCPE, adjusts the above density $f(y|\mu,\sigma,\nu,\tau)$ for the
truncation resulting from the condition $y>0$. See Rigby and Stasinopoulos (2003) for details.gamlss.family, BCT# BCPE() #
# library(gamlss)
# data(abdom)
#h<-gamlss(y~cs(x,df=3), sigma.formula=~cs(x,1), family=BCPE, data=abdom)
#plot(h)
plot(function(x)dBCPE(x, mu=5,sigma=.5,nu=1, tau=3), 0.0, 15,
main = "The BCPE density mu=5,sigma=.5,nu=1, tau=3")
plot(function(x) pBCPE(x, mu=5,sigma=.5,nu=1, tau=3), 0.0, 15,
main = "The BCPE cdf mu=5, sigma=.5, nu=1, tau=3")Run the code above in your browser using DataLab