GB2 creates a gamlss.family object which can be used to fit the distribution using the function
gamlss(). The response variable is
in the range from zero to infinity.
The functions dGB2,
GB2, qGB2 and rGB2 define the density,
distribution function, quantile function and random
generation for the generalized beta type 2 distribution.
The generalised Pareto GP distribution is defined by setting the parameters sigma and nu of the GB2 distribution to 1.GB2(mu.link = "log", sigma.link = "identity", nu.link = "log",
tau.link = "log")
dGB2(x, mu = 1, sigma = 1, nu = 1, tau = 0.5, log = FALSE)
pGB2(q, mu = 1, sigma = 1, nu = 1, tau = 0.5, lower.tail = TRUE,
log.p = FALSE)
qGB2(p, mu = 1, sigma = 1, nu = 1, tau = 0.5, lower.tail = TRUE,
log.p = FALSE)
rGB2(n, mu = 1, sigma = 1, nu = 1, tau = 0.5)GP(mu.link = "log", sigma.link = "log")
dGP(x, mu = 1, sigma = 1, log = FALSE)
pGP(q, mu = 1, sigma = 1, lower.tail = TRUE, log.p = FALSE)
qGP(p, mu = 1, sigma = 1, lower.tail = TRUE, log.p = FALSE)
rGP(n, mu = 1, sigma = 1)
mu.link, with "identity" link as the default for the mu parameter.sigma.link, with "log" link as the default for the sigma parameter.nu.link, with "log" link as the default for the nu parameter.tau.link, with "log" link as the default for the tau parameter.nu parameter valuestau parameter valueslength(n) > 1, the length is
taken to be the number requiredGB2() returns a gamlss.family object which can be used to fit the GB2 distribution in the
gamlss() function.
dGB2() gives the density, pGB2() gives the distribution
function, qGB2() gives the quantile function, and rGB2()
generates random deviates.GB2), is defined as
$$f(y|\mu,\sigma\,\nu,\tau)= |\sigma| y^{\mbox{\hspace{0.01cm}}\sigma \mbox{\hspace{0.01cm}}v-1 } {\mu^{\sigma \nu}\mbox{\hspace{0.05cm}}B(\nu,\tau) \mbox{\hspace{0.05cm}} [1+(y/\mu)^\sigma]^{\nu+\tau}}^{-1}$$where $y > 0$, $\mu>0$, $-\infty <\sigma <\infty$,="" $\nu="">0$ and $\tau>0$. .\sigma>
Stasinopoulos D. M. Rigby R. A. and Akantziliotou C. (2006) Instructions on how to use the GAMLSS package in R.
Accompanying documentation in the current GAMLSS help files, (see also
Stasinopoulos D. M. Rigby R.A. (2007) Generalized additive models for location scale and shape (GAMLSS) in R.
Journal of Statistical Software, Vol. 23, Issue 7, Dec 2007,
gamlss.family, JSU, BCTGB2() #
y<- rGB2(200, mu=5, sigma=2, nu=1, tau=1)
library(MASS)
truehist(y)
fx<-dGB2(seq(0.01, 20, length=200), mu=5 ,sigma=2, nu=1, tau=1)
lines(seq(0.01,20,length=200),fx)
integrate(function(x) x*dGB2(x=x, mu=5, sigma=2, nu=1, tau=1), 0, Inf)
mean(y)
curve(dGB2(x, mu=5 ,sigma=2, nu=1, tau=1), 0.01, 20,
main = "The GB2 density mu=5, sigma=2, nu=1, tau=4")Run the code above in your browser using DataLab