gamlss.family object to be used in GAMLSS fitting using the function gamlss().
The functions DIG, pGIG, GIG and rGIG define the density,
distribution function, quantile function and random generation for the specific parameterization
of the generalized inverse gaussian distribution defined by function GIG.
GIG(mu.link = "log", sigma.link = "log", nu.link = "identity")
dGIG(x, mu=1, sigma=1, nu=1, log = FALSE)
pGIG(q, mu=1, sigma=1, nu=1, lower.tail = TRUE, log.p = FALSE)
qGIG(p, mu=1, sigma=1, nu=1, lower.tail = TRUE, log.p = FALSE)
rGIG(n, mu=1, sigma=1, nu=1, ...)mu parameter,
other links are "inverse" and "identity" sigma parameter,
other links are "inverse" and "identity" nu parameter,
other links are "inverse" and "log"Stasinopoulos D. M., Rigby R.A. and Akantziliotou C. (2006) Instructions on how to use the GAMLSS package in R. Accompanying documentation in the current GAMLSS help files, (see also http://www.gamlss.org/).
Stasinopoulos D. M. Rigby R.A. (2007) Generalized additive models for location scale and shape (GAMLSS) in R. Journal of Statistical Software, Vol. 23, Issue 7, Dec 2007, http://www.jstatsoft.org/v23/i07.
Jorgensen B. (1982) Statistical properties of the generalized inverse Gaussian distribution, Series: Lecture notes in statistics; 9, New York : Springer-Verlag.
gamlss.family, IGy<-rGIG(100,mu=1,sigma=1, nu=-0.5) # generates 1000 random observations
hist(y)
# library(gamlss)
# histDist(y, family=GIG)
Run the code above in your browser using DataLab