RGE defines the reverse generalized extreme family distribution, a three parameter distribution,
for a gamlss.family object to be used in GAMLSS fitting using the function gamlss().
The functions dRGE, pRGE, qRGE and rRGE define the density, distribution function, quantile function and random
generation for the specific parameterization of the reverse generalized extreme distribution given in details below.RGE(mu.link = "identity", sigma.link = "log", nu.link = "log")
dRGE(x, mu = 1, sigma = 0.1, nu = 1, log = FALSE)
pRGE(q, mu = 1, sigma = 0.1, nu = 1, lower.tail = TRUE, log.p = FALSE)
qRGE(p, mu = 1, sigma = 0.1, nu = 1, lower.tail = TRUE, log.p = FALSE)
rRGE(n, mu = 1, sigma = 0.1, nu = 1)mu.link, with "identity" link as the default for the mu parametersigma.link, with "log" link as the default for the sigma parameternu.link, with "log" link as the default for the nu parameterlength(n) > 1, the length is
taken to be the number requiredRGE() returns a gamlss.family object which can be used to fit a reverse generalized extreme distribution in the gamlss() function.
dRGE() gives the density, pRGE() gives the distribution
function, qRGE() gives the quantile function, and rRGE()
generates random deviates.gamlss.familyRGE()# gives information about the default links for the reverse generalized extreme family distribution
newdata<-rRGE(100,mu=0,sigma=1,nu=5) # generates 100 random observations
# library(gamlss)
# gamlss(newdata~1, family=RGE, method=mixed(5,50)) # difficult to converseRun the code above in your browser using DataLab