gamlss.family object to be used for a
GAMLSS fitting using the function gamlss(). The functions dSEP,
pSEP, qSEP and rSEP define the density,
distribution function, quantile function and random
generation for the Skew Power exponential (SEP) distribution.
SEP(mu.link = "identity", sigma.link = "log", nu.link = "identity", tau.link = "log")
dSEP(x, mu = 0, sigma = 1, nu = 0, tau = 2, log = FALSE)
pSEP(q, mu = 0, sigma = 1, nu = 0, tau = 2, lower.tail = TRUE, log.p = FALSE)
qSEP(p, mu = 0, sigma = 1, nu = 0, tau = 2, lower.tail = TRUE, log.p = FALSE, lower.limit = mu - 5 * sigma, upper.limit = mu + 5 * sigma)
rSEP(n, mu = 0, sigma = 1, nu = 0, tau = 2)mu.link, with "identity" link as the default for the mu parameter. Other links are "$1/mu^2$" and "log"sigma.link, with "log" link as the default for the sigma parameter. Other links are "inverse" and "identity"nu.link, with "identity" link as the default for the nu parameter. Other links are "$1/nu^2$" and "log"tau.link, with "log" link as the default for the tau parameter. Other links are "$1/tau^2$", and "identitynu parameter valuestau parameter valueslength(n) > 1, the length is
taken to be the number requiredSEP() returns a gamlss.family object which can be used to fit the SEP distribution in the gamlss() function.
dSEP() gives the density, pSEP() gives the distribution
function, qSEP() gives the quantile function, and rSEP()
generates random deviates.
SEP), is defined as
$$f(y|n,\mu,\sigma\,\nu,\tau)==\frac{z}{\sigma} \Phi(\omega) \hspace{1mm} f_{EP}(z,0,1,\tau) $$for $0
Rigby, R. A. and Stasinopoulos D. M. (2005). Generalized additive models for location, scale and shape,(with discussion), Appl. Statist., 54, part 3, pp 507-554.
Stasinopoulos D. M. Rigby R. A. and Akantziliotou C. (2006) Instructions on how to use the GAMLSS package in R. Accompanying documentation in the current GAMLSS help files, (see also http://www.gamlss.org/).
Stasinopoulos D. M. Rigby R.A. (2007) Generalized additive models for location scale and shape (GAMLSS) in R. Journal of Statistical Software, Vol. 23, Issue 7, Dec 2007, http://www.jstatsoft.org/v23/i07.
gamlss.family, JSU, BCTSEP() #
plot(function(x)dSEP(x, mu=0,sigma=1, nu=1, tau=2), -5, 5,
main = "The SEP density mu=0,sigma=1,nu=1, tau=2")
plot(function(x) pSEP(x, mu=0,sigma=1,nu=1, tau=2), -5, 5,
main = "The BCPE cdf mu=0, sigma=1, nu=1, tau=2")
dat <- rSEP(100,mu=10,sigma=1,nu=-1,tau=1.5)
# library(gamlss)
# gamlss(dat~1,family=SEP, control=gamlss.control(n.cyc=30))
Run the code above in your browser using DataLab