dSEP1, dSEP2, dSEP3 and dSEP4 define the probability distribution functions,
the functions pSEP1, pSEP2, pSEP3 and pSEP4 define the cumulative distribution functions
the functions qSEP1, qSEP2, qSEP3 and qSEP4 define the inverse cumulative distribution functions and
the functions rSEP1, rSEP2, rSEP3 and rSEP4 define the random generation for the Skew exponential power
distributions.SEP1(mu.link = "identity", sigma.link = "log", nu.link = "identity",
tau.link = "log")
dSEP1(x, mu = 0, sigma = 1, nu = 0, tau = 2, log = FALSE)
pSEP1(q, mu = 0, sigma = 1, nu = 0, tau = 2, lower.tail = TRUE,
log.p = FALSE)
qSEP1(p, mu = 0, sigma = 1, nu = 0, tau = 2, lower.tail = TRUE,
log.p = FALSE)
rSEP1(n, mu = 0, sigma = 1, nu = 0, tau = 2)
SEP2(mu.link = "identity", sigma.link = "log", nu.link = "identity",
tau.link = "log")
dSEP2(x, mu = 0, sigma = 1, nu = 0, tau = 2, log = FALSE)
pSEP2(q, mu = 0, sigma = 1, nu = 0, tau = 2, lower.tail = TRUE,
log.p = FALSE)
qSEP2(p, mu = 0, sigma = 1, nu = 0, tau = 2, lower.tail = TRUE,
log.p = FALSE)
rSEP2(n, mu = 0, sigma = 1, nu = 0, tau = 2)
SEP3(mu.link = "identity", sigma.link = "log", nu.link = "log",
tau.link = "log")
dSEP3(x, mu = 0, sigma = 1, nu = 2, tau = 2, log = FALSE)
pSEP3(q, mu = 0, sigma = 1, nu = 2, tau = 2, lower.tail = TRUE,
log.p = FALSE)
qSEP3(p, mu = 0, sigma = 1, nu = 2, tau = 2, lower.tail = TRUE,
log.p = FALSE)
SEP4(mu.link = "identity", sigma.link = "log", nu.link = "log",
tau.link = "log")
dSEP4(x, mu = 0, sigma = 1, nu = 2, tau = 2, log = FALSE)
pSEP4(q, mu = 0, sigma = 1, nu = 2, tau = 2, lower.tail = TRUE,
log.p = FALSE)
qSEP4(p, mu = 0, sigma = 1, nu = 2, tau = 2, lower.tail = TRUE,
log.p = FALSE)
rSEP4(n, mu = 0, sigma = 1, nu = 2, tau = 2)mu.link, with "identity" link as the default for the mu parameter. Other links are "inverse" and "log"sigma.link, with "log" link as the default for the sigma parameter. Other links are "inverse" and "identity"nu.link, with "log" link as the default for the nu parameter. Other links are "identity" and "inverse"tau.link, with "log" link as the default for the tau parameter. Other links are "inverse", and "identitynu parameter valuestau parameter valueslength(n) > 1, the length is
taken to be the number requiredSEP2() returns a gamlss.family object which can be used to fit the SEP2 distribution in the gamlss() function.
dSEP2() gives the density, pSEP2() gives the distribution
function, qSEP2() gives the quantile function, and rSEP2()
generates random deviates.SEP2), is defined as
$$f_Y(y|\mu,\sigma\,\nu,\tau)=\frac{\nu}{\sigma (1+\nu^2)2^{1/\tau} \Gamma(1+1/\tau)}\left{\exp\left(- \frac{1}{2} \left|\frac{\nu (y-\mu)}{\sigma} \right|^\tau \right) I(y<\mu)+\exp\left(- \frac{1}{2}="" \left|\frac{(y-\mu)}{\sigma="" \nu}="" \right|^\tau="" \right)="" i(y="" \geq="" \mu)\right}$$="" for="" $-\infty="" <="" y="" \infty$,="" $\mu="(-\infty,+\infty)$," $\sigma="">0$,
$\nu>0)$ and
$\tau>0$.\mu)+\exp\left(->gamlss.family, SEPSEP1()
curve(dSEP4(x, mu=5 ,sigma=1, nu=2, tau=1.5), -2, 10, main = "The SEP4 density mu=5 ,sigma=1, nu=1, tau=1.5")
# library(gamlss)
#y<- rSEP4(100, mu=5, sigma=1, nu=2, tau=1.5);hist(y)
#m1<-gamlss(y~1, family=SEP1, n.cyc=50)
#m2<-gamlss(y~1, family=SEP2, n.cyc=50)
#m3<-gamlss(y~1, family=SEP3, n.cyc=50)
#m4<-gamlss(y~1, family=SEP4, n.cyc=50)
#GAIC(m1,m2,m3,m4)Run the code above in your browser using DataLab