dST3, pST3, qST3 and rST3 define the density, distribution function,
quantile function and random generation for the skew t distribution type 3.ST1(mu.link = "identity", sigma.link = "log", nu.link = "identity", tau.link="log")
dST1(y, mu = 0, sigma = 1, nu = 0, tau = 2, log = FALSE)
pST1(q, mu = 0, sigma = 1, nu = 0, tau = 2, lower.tail = TRUE, log.p = FALSE)
qST1(p, mu = 0, sigma = 1, nu = 0, tau = 2, lower.tail = TRUE, log.p = FALSE)
rST1(n, mu = 0, sigma = 1, nu = 0, tau = 2)
ST2(mu.link = "identity", sigma.link = "log", nu.link = "identity", tau.link = "log")
dST2(y, mu = 0, sigma = 1, nu = 0, tau = 2, log = FALSE)
pST2(q, mu = 0, sigma = 1, nu = 0, tau = 2, lower.tail = TRUE, log.p = FALSE)
qST2(p, mu = 1, sigma = 1, nu = 0, tau = 2, lower.tail = TRUE, log.p = FALSE)
rST2(n, mu = 0, sigma = 1, nu = 0, tau = 2)
ST3(mu.link = "identity", sigma.link = "log", nu.link = "log", tau.link = "log")
dST3(y, mu = 0, sigma = 1, nu = 1, tau = 10, log = FALSE)
pST3(q, mu = 0, sigma = 1, nu = 1, tau = 10, lower.tail = TRUE, log.p = FALSE)
qST3(p, mu = 0, sigma = 1, nu = 1, tau = 10, lower.tail = TRUE, log.p = FALSE)
rST3(n, mu = 0, sigma = 1, nu = 1, tau = 10)
ST4(mu.link = "identity", sigma.link = "log", nu.link = "log", tau.link = "log")
dST4(y, mu = 0, sigma = 1, nu = 1, tau = 10, log = FALSE)
pST4(q, mu = 0, sigma = 1, nu = 1, tau = 10, lower.tail = TRUE, log.p = FALSE)
qST4(p, mu = 0, sigma = 1, nu = 1, tau = 10, lower.tail = TRUE, log.p = FALSE)
rST4(n, mu = 0, sigma = 1, nu = 1, tau = 10)
ST5(mu.link = "identity", sigma.link = "log", nu.link = "identity", tau.link = "log")
dST5(y, mu = 0, sigma = 1, nu = 0, tau = 1, log = FALSE)
pST5(q, mu = 0, sigma = 1, nu = 0, tau = 1, lower.tail = TRUE, log.p = FALSE)
qST5(p, mu = 0, sigma = 1, nu = 0, tau = 1, lower.tail = TRUE, log.p = FALSE)
rST5(n, mu = 0, sigma = 1, nu = 0, tau = 1)mu.link, with "identity" link as the default for the mu parameter.
Other links are "$1/mu^2$" and "log"sigma.link, with "log" link as the default for the sigma parameter.
Other links are "inverse" and "identity"nu.link, with "identity" link as the default for the nu parameter.
Other links are "$1/mu^2$" and "log"nu.link, with "log" link as the default for the nu parameter.
Other links are "inverse", "identity"mu parameter valuesnu parameter valuestau parameter valueslength(n) > 1, the length is
taken to be the number requiredST1(), ST2(), ST3(), ST4() and ST5() return a gamlss.family object
which can be used to fit the skew t type 1-5 distribution in the gamlss() function.
dST1(), dST2(), dST3(), dST4() and dST5() give the density functions,
pST1(), pST2(), pST3(), pST4() and pST5() give the cumulative distribution functions,
qST1(), qST2(), qST3(), qST4() and qST5() give the quantile function, and
rST1(), rST2(), rST3(), rST4() and rST3() generates random deviates.ST1), Azzalini (1986) is defined as
$$f(y|\mu,\sigma,\nu, \tau)=\frac{z}{\sigma} \mbox{\hspace{0.1cm}}f_z(z) \mbox{\hspace{0.1cm}} F_z(\nu z)$$
for $-\inftyST2), Azzalini and Capitano (2003),
is defined as
$$f(y|\mu,\sigma,\nu,\frac{z}{\sigma} \mbox{\hspace{0.1cm}} f_{z_1}(z) \mbox{\hspace{0.1cm}} F_{z_2}(w) \tau)=$$
for $-\inftyST4), is defined in Chapter of the
GAMLSS manual.
The probability density function of the skew t distribution type 5, (ST5), is defined as
$$f(y|\mu,\sigma,\nu, \tau)=\frac{1}{c} \left[ 1+ \frac{z}{(a+b +z^2)^{1/2}} \right]^{a+1/2} \left[ 1- \frac{z}{(a+b+z^2)^{1/2}}\right]^{b+1/2}$$
where $c=2^{a +b-1} (a+b)^{1/2} B(a,b)$, and
$B(a,b)=\Gamma(a)\Gamma(b)/ \Gamma(a+b)$ and
$z=(y-\mu)/\sigma$ and
$\nu=(a-b)/\left[ab(a+b) \right]^{1/2}$
and
$\tau=2/(a+b)$
for $-\inftygamlss, gamlss.family, BCCG, GA, IG LNOy<- rST5(200, mu=5, sigma=1, nu=.1)
hist(y)
m1<-gamlss(y~1, family=ST1)
m2<-gamlss(y~1, family=ST2)
m3<-gamlss(y~1, family=ST3)
m4<-gamlss(y~1, family=ST4)
m5<-gamlss(y~1, family=ST5)
GAIC(m1,m2,m3,m4,m5)
curve(dST5(y=x, mu=30 ,sigma=5,nu=-1), -50, 50, main = "The ST5 density mu=30 ,sigma=5,nu=1")Run the code above in your browser using DataLab