ZABI() function defines the zero adjusted binomial distribution, a two parameter distribution,
for a gamlss.family object to be used
in GAMLSS fitting using the function gamlss().
The functions dZABI, pZABI, qZABI and rZABI define the density, distribution function, quantile function and random
generation for the zero adjusted binomial, ZABI(), distribution. The ZIBI() function defines the zero inflated binomial distribution, a two parameter distribution,
for a gamlss.family object to be used
in GAMLSS fitting using the function gamlss().
The functions dZIBI, pZIBI, qZIBI and rZIBI define the density, distribution function, quantile function and random
generation for the zero inflated binomial, ZIBI(), distribution.
ZABI(mu.link = "logit", sigma.link = "logit")
dZABI(x, bd = 1, mu = 0.5, sigma = 0.1, log = FALSE)
pZABI(q, bd = 1, mu = 0.5, sigma = 0.1, lower.tail = TRUE, log.p = FALSE)
qZABI(p, bd = 1, mu = 0.5, sigma = 0.1, lower.tail = TRUE, log.p = FALSE)
rZABI(n, bd = 1, mu = 0.5, sigma = 0.1)
ZIBI(mu.link = "logit", sigma.link = "logit")
dZIBI(x, bd = 1, mu = 0.5, sigma = 0.1, log = FALSE)
pZIBI(q, bd = 1, mu = 0.5, sigma = 0.1, lower.tail = TRUE, log.p = FALSE)
qZIBI(p, bd = 1, mu = 0.5, sigma = 0.1, lower.tail = TRUE, log.p = FALSE)
rZIBI(n, bd = 1, mu = 0.5, sigma = 0.1)mu.link, with "logit" link as the default for the mu parameter.
Other links are "probit" and "cloglog"'(complementary log-log)sigma.link, with "logit" link as the default for the mu parameter.
Other links are "probit" and "cloglog"'(complementary log-log)ZABI and ZIBI return a gamlss.family object which
can be used to fit a binomial distribution in the gamlss() function.
Stasinopoulos D. M., Rigby R.A. and Akantziliotou C. (2006) Instructions on how to use the GAMLSS package in R. Accompanying documentation in the current GAMLSS help files, (see also http://www.gamlss.org/).
Stasinopoulos D. M. Rigby R.A. (2007) Generalized additive models for location scale and shape (GAMLSS) in R. Journal of Statistical Software, Vol. 23, Issue 7, Dec 2007, http://www.jstatsoft.org/v23/i07.
Rigby, R. A. and Stasinopoulos D. M. (2010) The gamlss.family distributions, (distributed with this package or see http://www.gamlss.org/)
gamlss.family, BIZABI()
curve(dZABI(x, mu = .5, bd=10), from=0, to=10, n=10+1, type="h")
tN <- table(Ni <- rZABI(1000, mu=.2, sigma=.3, bd=10))
r <- barplot(tN, col='lightblue')
ZIBI()
curve(dZIBI(x, mu = .5, bd=10), from=0, to=10, n=10+1, type="h")
tN <- table(Ni <- rZIBI(1000, mu=.2, sigma=.3, bd=10))
r <- barplot(tN, col='lightblue')
Run the code above in your browser using DataLab