ZINBI defines the zero inflated negative binomial distribution, a three parameter distribution, for a
gamlss.family object to be used in GAMLSS fitting using the function gamlss(). The functions dZINBI, pZINBI,
qZINBI and rZINBI define the
density, distribution function, quantile function
and random generation for the zero inflated negative binomial, ZINBI(), distribution.
The function ZANBI defines the zero adjusted negative binomial distribution, a three parameter distribution, for a
gamlss.family object to be used in GAMLSS fitting using the function gamlss(). The functions dZANBI, pZANBI,
qZANBI and rZANBI define the
density, distribution function, quantile function
and random generation for the zero inflated negative binomial, ZANBI(), distribution.ZINBI(mu.link = "log", sigma.link = "log", nu.link = "logit")
dZINBI(x, mu = 1, sigma = 1, nu = 0.3, log = FALSE)
pZINBI(q, mu = 1, sigma = 1, nu = 0.3, lower.tail = TRUE, log.p = FALSE)
qZINBI(p, mu = 1, sigma = 1, nu = 0.3, lower.tail = TRUE, log.p = FALSE)
rZINBI(n, mu = 1, sigma = 1, nu = 0.3)
ZANBI(mu.link = "log", sigma.link = "log", nu.link = "logit")
dZANBI(x, mu = 1, sigma = 1, nu = 0.3, log = FALSE)
pZANBI(q, mu = 1, sigma = 1, nu = 0.3, lower.tail = TRUE, log.p = FALSE)
qZANBI(p, mu = 1, sigma = 1, nu = 0.3, lower.tail = TRUE, log.p = FALSE)
rZANBI(n, mu = 1, sigma = 1, nu = 0.3)mu.link, with "log" link as the default for the mu parametersigma.link, with "log" link as the default for the sigma parametermu.link, with "logit" link as the default for the nu parameterZINBI and ZANBI return a gamlss.family object which can be used to fit a
zero inflated or zero adjusted Negative Binomial type I distribution respectively in the gamlss() function.gamlss.family, NBI, NBIIZINBI()
ZANBI()
# creating data and plotting them
dat <- rZINBI(1000, mu=5, sigma=.5, nu=0.1)
r <- barplot(table(dat), col='lightblue')
dat1 <- rZANBI(1000, mu=5, sigma=.5, nu=0.1)
r1 <- barplot(table(dat1), col='lightblue')Run the code above in your browser using DataLab